@@ -12,10 +12,21 @@ import os, sys
 if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
+from zope.component import getUtility
+
 from Testing import ZopeTestCase
+
 from Products.CMFPlone.tests import PloneTestCase
+
+from bibliograph.rendering.interfaces import IBibliographyRenderer
+from bibliograph.rendering.utility import BibtexRenderer
+from bibliograph.parsing.interfaces import IBibliographyParser
+from bibliograph.parsing.parsers.bibtex import BibtexParser
+from bibliograph.parsing.parsers.medline import MedlineParser
+
 from Products.CMFBibliographyAT.tests import setup
 
+
 class TestCMFBibliographyATInstall(PloneTestCase.PloneTestCase):
     '''Test the CMFBibliographyAT installation'''
 
@@ -23,7 +34,7 @@ class TestCMFBibliographyATInstall(PloneTestCase.PloneTestCase):
         pass
 
     # the individual tests
-    
+
     def testSkinInstallation(self):
         st = self.portal.portal_skins
         self.failUnless('bibliography' in st.objectIds())
@@ -32,25 +43,18 @@ class TestCMFBibliographyATInstall(PloneTestCase.PloneTestCase):
         root = self.portal
         self.failUnless('portal_bibliography' in root.objectIds())
 
-    def testParserFolderInstallation(self):
-        bibtool = self.portal.portal_bibliography
-        self.failUnless('Parsers' in bibtool.objectIds())
-
-    def testRendererFolderInstallation(self):
-        bibtool = self.portal.portal_bibliography
-        self.failUnless('Renderers' in bibtool.objectIds())
-
     def testBibtexParserInstallation(self):
-        parsers = self.portal.portal_bibliography.Parsers
-        self.failUnless('bibtex' in parsers.objectIds())
+        parser = getUtility(IBibliographyParser, name='bibtex')
+        self.failUnless(isinstance(parser, BibtexParser))
 
     def testMedlineParserInstallation(self):
-        parsers = self.portal.portal_bibliography.Parsers
-        self.failUnless('medline' in parsers.objectIds())
+        parser = getUtility(IBibliographyParser, name='medline')
+        self.failUnless(isinstance(parser, MedlineParser))
 
     def testBibtexRendererInstallation(self):
-        renderers = self.portal.portal_bibliography.Renderers
-        self.failUnless('bibtex' in renderers.objectIds())
+        util = getUtility(IBibliographyRenderer, name='bibtex')
+        self.failUnless(isinstance(util, BibtexRenderer))
+
 
     def testBibFolderInstallation(self):
         ttool = self.portal.portal_types
@@ -90,7 +94,7 @@ class TestCMFBibliographyATInstall(PloneTestCase.PloneTestCase):
 
         newFieldIndexes = ['Authors', 'publication_year']
         newSchemaEntries = ['Authors', 'publication_year', 'Source']
-        
+
         for idx in newFieldIndexes:
             self.failUnless(idx in ctool.indexes())
 
@@ -108,6 +112,15 @@ class TestCMFBibliographyATInstall(PloneTestCase.PloneTestCase):
         action_ids = [a.id for a in acttool.listActions()]
         self.failUnless('bibliography_search' in action_ids)
 
+    def testExistencePropertySheet(self):
+        pp = self.portal.portal_properties
+        self.assertEqual('cmfbibat_properties' in pp.objectIds(), True)
+
+    def testDefaultValuesInPropertySheet(self):
+        bib_tool = self.portal.portal_bibliography
+        self.assertEqual(bib_tool.getSheetProperty('BibTeX', 'parser_enabled'), True)
+        self.assertEqual(bib_tool.getSheetProperty('BibTeX', 'renderer_enabled'), True)
+
     # end of the individual tests
 
 def test_suite():
